formattools.get_stem_tremolo_format_contributions
=================================================

.. autofunction:: abjad.tools.formattools.get_stem_tremolo_format_contributions.get_stem_tremolo_format_contributions
   :noindex:
